from django.conf import settings

class AuthorRouter(object):
     def db_for_read(self, model, **hints):
          """
          Attempts to read author models go to site db.
          """
          if model._meta.app_label == 'authors':
               return 'site'
          return None
     
     def db_for_write(self, model, **hints):
          """
          Attempts to write author models go to site db
          """
          if model._meta.app_label == 'authors':
               return 'site'
          return None
     
     def allow_relation(self, obj1, obj2, **hints):
          """
          Allow relations if a model in the authors app is involved.
          """
          if obj1._meta.app_label == 'authors' or \
                   obj2._meta.app_label == 'authors':
               return True
          return None
     
     def allow_syncdb(self, db, model):
          """
          Make sure the authors app only appears in the 'site'
          database.
          """
          if db == 'site':
               return model._meta.app_label == 'authors'
          elif model._meta.app_label == 'authors':
               return False
          return None
     



from django.db import models
from plicata.books.models import Book
from mezzanine.core.fields import RichTextField

class Setting(models.Model):
    name = models.CharField(max_length=80, unique=True)
    tagline = models.CharField(max_length=255, blank=True, null=True)
    setting = RichTextField(blank=True, null=True)
    books = models.ManyToManyField(Book)
    def __unicode__(self):
        return self.name
    class Meta:
        db_table = 'plicta_setting_setting'



from django.contrib import admin
from mezzanine.pages.admin import PageAdmin
from books.models import Book,Genre,Publisher, BookPage

class PublisherAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('publisher',)}

class GenreAdmin(admin.ModelAdmin):
    prepopulated_fields = {'slug': ('genre',)}

class BookPageAdmin(Page):
    prepopulated_field = {'title': ('page.bookpage.thebook.title',)}

admin.site.register(Genre, GenreAdmin)
admin.site.register(Publisher, PublisherAdmin)
admin.site.register(Book)
admin.site.register(BookPage, BookPageAdmin)



from django.conf.urls import patterns, include, url
from django.contrib import admin

from mezzanine.core.views import direct_to_template

admin.autodiscover()

urlpatterns = patterns(
    url(r"^sellsheet/$", direct_to_template, {"template": "sellsheet.html"}, name="sellsheet"),
    url(r"^reviews/$", direct_to_template, {"template": "reviews.html"}, name="reviews"),
    url(r"^excerpts/$", direct_to_template, {"template": "excerpts.html"}, name="excerpts"),
    url(r"^chapters/$", direct_to_template, {"template": "chapters.html"}, name="chapters"),
    url(r"^outline/$", direct_to_template, {"template": "outline.html"}, name="outline"),
)



from django.db import models
from plicata.books.models import Book
from mezzanine.core.models import Displayable, Ownable, RichText, Slugged
from mezzanine.core.fields import FileField, RichTextField

class Review(models.Model):
    book = models.ForeignKey(Book)
    visible = models.BooleanField(default=True)
    sortorder = models.IntegerField(default=999)
    reviewer = models.TextField(max_length=80)
    entity = models.TextField(max_length=80)
    citation = models.TextField(max_length=255)
    url = models.URLField()
    body = RichTextField()

class Quote(models.Model):
    review = models.ForeignKey(Review)
    visible = models.BooleanField(default=True)
    sortorder = models.IntegerField(default=999)
    quote = RichTextField()



from django.db import models


class Author(models.Model):
    lastname = models.CharField(max_length=80)
    firstname = models.CharField(max_length=80)
    displayname = models.CharField(max_length=80, null=True, blank=True)
    website = models.URLField(null=True, blank=True)
    tagline = models.CharField(max_length=255, null=True, blank=True)
    bio = models.TextField(null=True, blank=True)
    photo = models.ImageField(upload_to='images', null=True, blank=True)
    facebook = models.CharField(max_length=255, null=True, blank=True)
    twitter = models.CharField(max_length=255, null=True, blank=True)
    linkedin = models.CharField(max_length=255, null=True, blank=True)
    visible = models.BooleanField()
    sortorder = models.IntegerField(null=True, blank=True)

    class Meta:
        db_table = 'plicata_authors'
        abstract = False

    class Admin:
        pass


    def __unicode__(self):
        return '%s %s' % (self.firstname, self.lastname)